from volcengine.livesaas.LivesaasService import LivesaasService

if __name__ == '__main__':
    livesaasService = LivesaasService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    livesaasService.set_ak('AK')
    livesaasService.set_sk('SK')

    params = {
        'IsNeedTotalCount': "True",
        'PageNo': 1,
        'PageItemCount': 10,
        'Name': "",
        'Status': 0,
        'LiveTime': 0,
        'IsLockPreview': 0
    }

    resp = livesaasService.list_activity_api(params)
    # resp = await livesaasService.async_list_activity_api(params)
    print(resp)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from volcengine.tls.TLSService import TLSService
from volcengine.tls.tls_requests import *


if __name__ == "__main__":
    # 请查询控制台，填写以下参数值
    endpoint = ""
    access_key_id = ""
    access_key_secret = ""
    region = ""

    # 实例化TLS客户端
    tls_service = TLSService(endpoint, access_key_id, access_key_secret, region)

    # 创建机器组
    create_host_group_request = CreateHostGroupRequest(host_group_name="host-group-name", host_group_type="IP",
                                                       host_ip_list=["192.168.1.1", "192.168.1.2", "192.168.1.3"])
    create_host_group_response = tls_service.create_host_group(create_host_group_request)
    host_group_id = create_host_group_response.host_group_id

    # 获取指定机器组信息
    describe_host_group_request = DescribeHostGroupRequest(host_group_id)
    describe_host_group_response = tls_service.describe_host_group(describe_host_group_request)

    # 获取全部机器组信息
    describe_host_groups_request = DescribeHostGroupsRequest()
    describe_host_groups_response = tls_service.describe_host_groups(describe_host_groups_request)

    # 修改机器组
    modify_host_group_request = ModifyHostGroupRequest(host_group_id, host_group_name="change-host-group-name")
    modify_host_group_response = tls_service.modify_host_group(modify_host_group_request)

    # 查询机器组所有机器
    describe_hosts_request = DescribeHostsRequest(host_group_id)
    describe_hosts_response = tls_service.describe_hosts(describe_hosts_request)

    # 删除机器组内指定机器
    delete_host_request = DeleteHostRequest(host_group_id, ip="192.168.1.3")
    delete_host_response = tls_service.delete_host(delete_host_request)

    # 查询机器组的采集配置
    describe_host_group_rules_request = DescribeHostGroupRulesRequest(host_group_id)
    describe_host_group_rules_response = tls_service.describe_host_group_rules(describe_host_group_rules_request)

    # 删除机器组
    delete_host_group_request = DeleteHostGroupRequest(host_group_id)
    delete_host_group_response = tls_service.delete_host_group(delete_host_group_request)



# coding=utf-8

# HTTP request and response.
HTTP_GET = "GET"
HTTP_POST = "POST"
HTTP_DELETE = "DELETE"
HTTP_PUT = "PUT"

HTTP_PREFIX = "http://"
HTTPS_PREFIX = "https://"

CONTENT_TYPE = "Content-Type"
APPLICATION_JSON = "application/json"
APPLICATION_X_PROTOBUF = "application/x-protobuf"
CONTENT_MD5 = "Content-MD5"

X_SECURITY_TOKEN = "X-Security-Token"
X_TLS_REQUEST_ID = "X-Tls-Requestid"
X_TLS_HASHKEY = "x-tls-hashkey"
X_TLS_COMPRESSTYPE = "x-tls-compresstype"
X_TLS_BODYRAWSIZE = "x-tls-bodyrawsize"
X_TLS_CURSOR = "X-Tls-Cursor"
X_TLS_COUNT = "X-Tls-Count"

PARAMS = "Params"
BODY = "Body"
REQUEST_HEADERS = "RequestHeaders"

OK_STATUS = 200

# TLS APIs
CREATE_PROJECT = "/CreateProject"
DELETE_PROJECT = "/DeleteProject"
MODIFY_PROJECT = "/ModifyProject"
DESCRIBE_PROJECT = "/DescribeProject"
DESCRIBE_PROJECTS = "/DescribeProjects"

CREATE_TOPIC = "/CreateTopic"
DELETE_TOPIC = "/DeleteTopic"
MODIFY_TOPIC = "/ModifyTopic"
DESCRIBE_TOPIC = "/DescribeTopic"
DESCRIBE_TOPICS = "/DescribeTopics"

PUT_LOGS = "/PutLogs"
DESCRIBE_CURSOR = "/DescribeCursor"
CONSUME_LOGS = "/ConsumeLogs"
SEARCH_LOGS = "/SearchLogs"

CREATE_INDEX = "/CreateIndex"
DELETE_INDEX = "/DeleteIndex"
MODIFY_INDEX = "/ModifyIndex"
DESCRIBE_INDEX = "/DescribeIndex"

DESCRIBE_SHARDS = "/DescribeShards"

CREATE_HOST_GROUP = "/CreateHostGroup"
DELETE_HOST_GROUP = "/DeleteHostGroup"
MODIFY_HOST_GROUP = "/ModifyHostGroup"
DESCRIBE_HOST_GROUP = "/DescribeHostGroup"
DESCRIBE_HOST_GROUPS = "/DescribeHostGroups"
DESCRIBE_HOSTS = "/DescribeHosts"
DELETE_HOST = "/DeleteHost"
DESCRIBE_HOST_GROUP_RULES = "/DescribeHostGroupRules"

CREATE_RULE = "/CreateRule"
DELETE_RULE = "/DeleteRule"
MODIFY_RULE = "/ModifyRule"
DESCRIBE_RULE = "/DescribeRule"
DESCRIBE_RULES = "/DescribeRules"
APPLY_RULE_TO_HOST_GROUPS = "/ApplyRuleToHostGroups"
DELETE_RULE_FROM_HOST_GROUPS = "/DeleteRuleFromHostGroups"

CREATE_ALARM_NOTIFY_GROUP = "/CreateAlarmNotifyGroup"
DELETE_ALARM_NOTIFY_GROUP = "/DeleteAlarmNotifyGroup"
MODIFY_ALARM_NOTIFY_GROUP = "/ModifyAlarmNotifyGroup"
DESCRIBE_ALARM_NOTIFY_GROUPS = "/DescribeAlarmNotifyGroups"
CREATE_ALARM = "/CreateAlarm"
DELETE_ALARM = "/DeleteAlarm"
MODIFY_ALARM = "/ModifyAlarm"
DESCRIBE_ALARMS = "/DescribeAlarms"

# TLS API fields
DATA = "Data"

REQUEST_ID = "RequestId"
DESCRIPTION = "Description"
PAGE_NUMBER = "PageNumber"
PAGE_SIZE = "PageSize"
TOTAL = "Total"
CREATE_TIME = "CreateTime"
MODIFY_TIME = "ModifyTime"

PROJECT_ID = "ProjectId"
PROJECT_NAME = "ProjectName"
REGION = "Region"
IS_FULL_NAME = "IsFullName"
PROJECTS = "Projects"

TOPIC_ID = "TopicId"
TOPIC_NAME = "TopicName"
TTL = "Ttl"
SHARD_COUNT = "ShardCount"
TOPICS = "Topics"

FULL_TEXT = "FullText"
KEY_VALUE = "KeyValue"
KEY = "Key"
VALUE = "Value"
CASE_SENSITIVE = "CaseSensitive"
DELIMITER = "Delimiter"
INCLUDE_CHINESE = "IncludeChinese"
VALUE_TYPE = "ValueType"
SQL_FLAG = "SqlFlag"

SHARD_ID = "ShardId"
SHARDS = "Shards"
LZ4 = "lz4"
FROM = "From"
CURSOR = "Cursor"
END_CURSOR = "EndCursor"
LOG_GROUP_COUNT = "LogGroupCount"
COMPRESSION = "Compression"
START_TIME = "StartTime"
END_TIME = "EndTime"
QUERY = "Query"
LIMIT = "Limit"
CONTEXT = "Context"
SORT = "Sort"
DESC = "desc"
ASC = "asc"
SCHEMA = "Schema"
TYPE = "Type"
RESULT_STATUS = "ResultStatus"
HIT_COUNT = "HitCount"
LIST_OVER = "ListOver"
ANALYSIS = "Analysis"
COUNT = "Count"
LOGS = "Logs"
ANALYSIS_RESULT = "AnalysisResult"

HOST_GROUP_ID = "HostGroupId"
HOST_GROUP_IDS = "HostGroupIds"
HOST_GROUP_NAME = "HostGroupName"
HOST_GROUP_TYPE = "HostGroupType"
IP = "Ip"
IP_TYPE = "IP"
LABEL = "Label"
HOST_IP_LIST = "HostIpList"
HOST_IDENTIFIER = "HostIdentifier"
HOST_GROUP_INFO = "HostGroupInfo"
HOST_GROUP_INFOS = "HostGroupInfos"
HOST_INFOS = "HostInfos"
HEARTBEAT_STATUS = "HeartbeatStatus"

RULE_ID = "RuleId"
RULE_NAME = "RuleName"
PATHS = "Paths"
LOG_TYPE = "LogType"
INPUT_TYPE = "InputType"
EXTRACT_RULE = "ExtractRule"
EXCLUDE_PATHS = "ExcludePaths"
USER_DEFINE_RULE = "UserDefineRule"
LOG_SAMPLE = "LogSample"
CONTAINER_RULE = "ContainerRule"
RULE_INFO = "RuleInfo"
RULE_INFOS = "RuleInfos"
HOST_GROUP_HOSTS_RULES_INFO = "HostGroupHostsRulesInfo"
HOST_GROUP_HOSTS_RULES_INFOS = "HostGroupHostsRulesInfos"
ENV_TAG = "EnvTag"
KUBERNETES_RULE = "KubernetesRule"
PARSE_PATH_RULE = "ParsePathRule"
PATH_SAMPLE = "PathSample"
BEGIN_REGEX = "BeginRegex"
LOG_REGEX = "LogRegex"
KEYS = "Keys"
TIME_KEY = "TimeKey"
TIME_FORMAT = "TimeFormat"
FILTER_KEY_REGEX = "FilterKeyRegex"
UN_MATCH_UP_LOAD_SWITCH = "UnMatchUpLoadSwitch"
UN_MATCH_LOG_KEY = "UnMatchLogKey"
REGEX = "Regex"
STREAM = "Stream"
CONTAINER_NAME_REGEX = "ContainerNameRegex"
INCLUDE_CONTAINER_LABEL_REGEX = "IncludeContainerLabelRegex"
EXCLUDE_CONTAINER_LABEL_REGEX = "ExcludeContainerLabelRegex"
INCLUDE_CONTAINER_ENV_REGEX = "IncludeContainerEnvRegex"
EXCLUDE_CONTAINER_ENV_REGEX = "ExcludeContainerEnvRegex"

ALARM_NOTIFY_GROUP_ID = "AlarmNotifyGroupId"
ALARM_NOTIFY_GROUP_NAME = "AlarmNotifyGroupName"
NOTIFY_TYPE = "NotifyType"
TRIGGER = "Trigger"
RECOVERY = "Recovery"
RECEIVERS = "Receivers"
RECEIVER_NAME = "ReceiverName"
ALARM_NOTIFY_GROUPS = "AlarmNotifyGroups"
ALARM_ID = "AlarmId"
ALARM_NAME = "AlarmName"
QUERY_REQUEST = "QueryRequest"
REQUEST_CYCLE = "RequestCycle"
CONDITION = "Condition"
ALARM_PERIOD = "AlarmPeriod"
ALARM_NOTIFY_GROUP = "AlarmNotifyGroup"
STATUS = "Status"
TRIGGER_PERIOD = "TriggerPeriod"
USER_DEFINE_MSG = "UserDefineMsg"
ALARMS = "Alarms"
TIME = "Time"
NUMBER = "Number"
START_TIME_OFFSET = "StartTimeOffset"
END_TIME_OFFSET = "EndTimeOffset"
RECEIVER_TYPE = "ReceiverType"
RECEIVER_NAMES = "ReceiverNames"
RECEIVER_CHANNELS = "ReceiverChannels"



from __future__ import print_function

import time

from volcengine.visual.VisualService import VisualService

if __name__ == '__main__':
    visual_service = VisualService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    visual_service.set_ak('ak')
    visual_service.set_sk('sk')

    params = {
        "product_id": "test",
        "image_id": "test",
        "category_id": 1,
        "url": "https://xxx",
        "custom_content": "custom",
        "int_attr": 1,
        "str_attr": "str",
        "crop": True,
        # "region": {
        #     'x1': 1,
        #     'x2': 2,
        #     'y1': 3,
        #     'y2': 4,
        # }
    }

    resp = visual_service.product_search_add_image(params)
    print(resp)



#  -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        'IpList': "1.1.1.1,2.2.2.2"
    }

    resp = svc.describe_iplist_info(body)
    print(resp)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import time

from volcengine.tls.TLSService import TLSService
from volcengine.tls.tls_requests import *


if __name__ == "__main__":
    # 请查询控制台，填写以下参数值
    endpoint = ""
    access_key_id = ""
    access_key_secret = ""
    region = ""

    # 实例化TLS客户端
    tls_service = TLSService(endpoint, access_key_id, access_key_secret, region)

    # 创建日志项目
    create_project_request = CreateProjectRequest(project_name="project-name", region=region,
                                                  description="project-description")
    create_project_response = tls_service.create_project(create_project_request)
    project_id = create_project_response.project_id

    # 创建日志主题
    create_topic_request = CreateTopicRequest(topic_name="topic-name", project_id=project_id,
                                              ttl=3650, description="topic-description", shard_count=2)
    create_topic_response = tls_service.create_topic(create_topic_request)
    topic_id = create_topic_response.topic_id

    # 创建索引
    full_text = FullTextInfo(case_sensitive=False, delimiter=",-;", include_chinese=False)
    value_info_a = ValueInfo(value_type="text", delimiter="", case_sensitive=True,
                             include_chinese=False, sql_flag=False)
    value_info_b = ValueInfo(value_type="long", delimiter="", case_sensitive=False,
                             include_chinese=False, sql_flag=True)
    key_value_info_a = KeyValueInfo(key="key1", value=value_info_a)
    key_value_info_b = KeyValueInfo(key="key2", value=value_info_b)
    key_value = [key_value_info_a, key_value_info_b]
    create_index_request = CreateIndexRequest(topic_id, full_text, key_value)
    create_index_response = tls_service.create_index(create_index_request)

    # 写入日志数据
    log_group_list = LogGroupList()

    log_group = log_group_list.log_groups.add()
    log_group.source = "127.0.0.1"
    log_group.filename = "sys.log"

    log = log_group.logs.add()
    log.time = 1346457600000

    log_content = log.contents.add()
    log_content.key = "key1"
    log_content.value = "error"

    put_logs_request = PutLogsRequest(topic_id, log_group_list, compression="lz4")
    tls_service.put_logs(put_logs_request)
    time.sleep(30)

    # 查询消费游标
    describe_cursor_request = DescribeCursorRequest(topic_id, shard_id=0, from_time="begin")
    describe_cursor_response = tls_service.describe_cursor(describe_cursor_request)

    # 消费日志数据
    consume_logs_request = ConsumeLogsRequest(topic_id, shard_id=0, cursor=describe_cursor_response.cursor)
    consume_logs_response = tls_service.consume_logs(consume_logs_request)

    # 查询日志数据（全文检索）
    search_logs_request = SearchLogsRequest(topic_id, query="error", limit=10,
                                            start_time=1346457600000, end_time=1630454400000)
    search_logs_response = tls_service.search_logs(search_logs_request)

    # 查询日志数据（键值检索）
    search_logs_request = SearchLogsRequest(topic_id, query="key1:error", limit=10,
                                            start_time=1346457600000, end_time=1630454400000)
    search_logs_response = tls_service.search_logs(search_logs_request)

    # 查询日志数据（SQL分析）
    search_logs_request = SearchLogsRequest(topic_id, query="* | select key1, key2", limit=10,
                                            start_time=1346457600000, end_time=1630454400000)
    search_logs_response = tls_service.search_logs(search_logs_request)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from volcengine.tls.TLSService import TLSService
from volcengine.tls.tls_requests import *


if __name__ == "__main__":
    # 请查询控制台，填写以下参数值
    endpoint = ""
    access_key_id = ""
    access_key_secret = ""
    region = ""

    # 实例化TLS客户端
    tls_service = TLSService(endpoint, access_key_id, access_key_secret, region)

    # 创建日志项目
    create_project_request = CreateProjectRequest(project_name="project-name", region=region,
                                                  description="project-description")
    create_project_response = tls_service.create_project(create_project_request)
    project_id = create_project_response.project_id

    # 创建日志主题
    create_topic_request = CreateTopicRequest(topic_name="topic-name", project_id=project_id,
                                              ttl=3650, description="topic-description", shard_count=2)
    create_topic_response = tls_service.create_topic(create_topic_request)
    topic_id = create_topic_response.topic_id

    # 创建告警组
    receiver = Receiver(receiver_type="User", receiver_names=["receiver-name"], receiver_channels=["Email", "Sms"],
                        start_time="00:00:00", end_time="23:59:59")
    create_alarm_notify_group_request = CreateAlarmNotifyGroupRequest(alarm_notify_group_name="alarm-notify-group-name",
                                                                      notify_type=["Trigger", "Recovery"],
                                                                      receivers=[receiver])
    create_alarm_notify_group_response = tls_service.create_alarm_notify_group(create_alarm_notify_group_request)
    alarm_notify_group_id = create_alarm_notify_group_response.alarm_notify_group_id

    # 获取告警组
    describe_alarm_notify_groups_request = DescribeAlarmNotifyGroupsRequest()
    describe_alarm_notify_groups_response = tls_service.describe_alarm_notify_groups(describe_alarm_notify_groups_request)

    # 修改告警组
    modify_alarm_notify_group_request = \
        ModifyAlarmNotifyGroupRequest(alarm_notify_group_id, alarm_notify_group_name="change-alarm-notify-group-name")
    modify_alarm_notify_group_response = tls_service.modify_alarm_notify_group(modify_alarm_notify_group_request)

    # 创建告警策略
    query_request = QueryRequest(topic_id=topic_id, query="Failed | select count(*) as errNum", number=1,
                                 start_time_offset=-15, end_time_offset=0)
    request_cycle = RequestCycle(cycle_type="Period", time=10)
    create_alarm_request = CreateAlarmRequest(project_id, alarm_name="alarm-name",
                                              query_request=[query_request], request_cycle=request_cycle,
                                              condition="$1.errNum>0", alarm_period=60,
                                              alarm_notify_group=[alarm_notify_group_id])
    create_alarm_response = tls_service.create_alarm(create_alarm_request)
    alarm_id = create_alarm_response.alarm_id

    # 查询告警策略
    describe_alarms_request = DescribeAlarmsRequest(project_id)
    describe_alarms_response = tls_service.describe_alarms(describe_alarms_request)

    # 修改告警策略
    modify_alarm_request = ModifyAlarmRequest(alarm_id, trigger_period=2)
    modify_alarm_response = tls_service.modify_alarm(modify_alarm_request)

    # 删除告警策略
    delete_alarm_request = DeleteAlarmRequest(alarm_id)
    delete_alarm_response = tls_service.delete_alarm(delete_alarm_request)

    # 删除告警组
    delete_alarm_notify_group_request = DeleteAlarmNotifyGroupRequest(alarm_notify_group_id)
    delete_alarm_notify_group_response = tls_service.delete_alarm_notify_group(delete_alarm_notify_group_request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tlog.proto\x12\x02pb\"(\n\nLogContent\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"5\n\x03Log\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12 \n\x08\x63ontents\x18\x02 \x03(\x0b\x32\x0e.pb.LogContent\"$\n\x06LogTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x08LogGroup\x12\x15\n\x04logs\x18\x01 \x03(\x0b\x32\x07.pb.Log\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x1c\n\x08log_tags\x18\x03 \x03(\x0b\x32\n.pb.LogTag\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontext_flow\x18\x05 \x01(\t\"0\n\x0cLogGroupList\x12 \n\nlog_groups\x18\x01 \x03(\x0b\x32\x0c.pb.LogGroupb\x06proto3')



_LOGCONTENT = DESCRIPTOR.message_types_by_name['LogContent']
_LOG = DESCRIPTOR.message_types_by_name['Log']
_LOGTAG = DESCRIPTOR.message_types_by_name['LogTag']
_LOGGROUP = DESCRIPTOR.message_types_by_name['LogGroup']
_LOGGROUPLIST = DESCRIPTOR.message_types_by_name['LogGroupList']
LogContent = _reflection.GeneratedProtocolMessageType('LogContent', (_message.Message,), {
  'DESCRIPTOR' : _LOGCONTENT,
  '__module__' : 'log_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogContent)
  })
_sym_db.RegisterMessage(LogContent)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
  'DESCRIPTOR' : _LOG,
  '__module__' : 'log_pb2'
  # @@protoc_insertion_point(class_scope:pb.Log)
  })
_sym_db.RegisterMessage(Log)

LogTag = _reflection.GeneratedProtocolMessageType('LogTag', (_message.Message,), {
  'DESCRIPTOR' : _LOGTAG,
  '__module__' : 'log_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogTag)
  })
_sym_db.RegisterMessage(LogTag)

LogGroup = _reflection.GeneratedProtocolMessageType('LogGroup', (_message.Message,), {
  'DESCRIPTOR' : _LOGGROUP,
  '__module__' : 'log_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogGroup)
  })
_sym_db.RegisterMessage(LogGroup)

LogGroupList = _reflection.GeneratedProtocolMessageType('LogGroupList', (_message.Message,), {
  'DESCRIPTOR' : _LOGGROUPLIST,
  '__module__' : 'log_pb2'
  # @@protoc_insertion_point(class_scope:pb.LogGroupList)
  })
_sym_db.RegisterMessage(LogGroupList)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGCONTENT._serialized_start=17
  _LOGCONTENT._serialized_end=57
  _LOG._serialized_start=59
  _LOG._serialized_end=112
  _LOGTAG._serialized_start=114
  _LOGTAG._serialized_end=150
  _LOGGROUP._serialized_start=152
  _LOGGROUP._serialized_end=271
  _LOGGROUPLIST._serialized_start=273
  _LOGGROUPLIST._serialized_end=321
# @@protoc_insertion_point(module_scope)



# coding:utf-8
import json

from volcengine.live.LiveService import LiveService

if __name__ == '__main__':
    live_service = LiveService()
    ak = ""
    sk = ""
    live_service.set_ak(ak)
    live_service.set_sk(sk)
    body = {
        "MessageType": "record",
        "Vhost": "vhost",
        "CallbackDetailList": [
            {
                "CallbackType": "callBackType",
                "URL": "demoUrl",
            },
        ],
    }
    resp = live_service.update_callback(body)
    print(resp)



#  -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        'Certificate': {
            'Certificate': '''-----BEGIN CERTIFICATE----- ... -----END CERTIFICATE-----''',
            'PrivateKey': '''-----BEGIN RSA PRIVATE KEY----- ... -----END RSA PRIVATE KEY-----'''
        },
        'CertInfo': {
            'Desc': 'remark',
        },
        'Source': 'volc_cert_center'
    }

    resp = svc.add_cdn_certificate(body)
    print(resp)



from volcengine.livesaas.LivesaasService import LivesaasService

if __name__ == '__main__':
    livesaasService = LivesaasService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    livesaasService.set_ak('AK')
    livesaasService.set_sk('SK')

    body = {
        "ActivityId": 1,
        "Media": {
            "Name": "test",
            "Vid": ""
        }
    }

    resp = livesaasService.upload_replay_api(body)
    # resp = await livesaasService.async_upload_replay_api(body)
    print(resp)



# coding:utf-8
from __future__ import print_function
from volcengine.imagex.ImageXService import ImageXService

if __name__ == '__main__':
    imagex_service = ImageXService()


    imagex_service.set_ak('ak')
    imagex_service.set_sk('sk')

    params = dict()
    params['ServiceId'] = 'service id'
    params['StoreUri'] = 'xx'
    params['Model'] = 0
    params['Top'] = 0.0
    params['Bottom'] = 0.0
    params['Left'] = 0.0
    params['Right'] = 0.0

    resp = imagex_service.get_image_bg_fill_result(params)
    print(resp)



#  -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")
import datetime

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)
    now = int(datetime.datetime.now().strftime("%s"))
    body = {
        'StartTime': now - 86400,
        'EndTime': now,
        'Metric': 'flux',
        'Item': 'domain'
    }
    print(body)

    resp = svc.describe_origin_top_nrt_data(body)
    print(resp)



# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo


class StsService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(StsService, "_instance"):
            with StsService._instance_lock:
                if not hasattr(StsService, "_instance"):
                    StsService._instance = object.__new__(cls)
        return StsService._instance

    def __init__(self):
        self.service_info = StsService.get_service_info()
        self.api_info = StsService.get_api_info()
        super(StsService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("sts.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'sts', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {"AssumeRole": ApiInfo("GET", "/", {"Action": "AssumeRole", "Version": "2018-01-01"}, {}, {})}
        return api_info

    def assume_role(self, params):
        res = self.get("AssumeRole", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json